"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const external_task_api_contracts_1 = require("@process-engine/external_task_api_contracts");
class ExternalTaskApiExternalAccessor {
    constructor(httpClient) {
        this.baseUrl = 'api/external_task/v1';
        this.httpClient = undefined;
        this.httpClient = httpClient;
    }
    async fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = external_task_api_contracts_1.restSettings.paths.fetchAndLockExternalTasks;
        url = this.applyBaseUrl(url);
        const payload = new external_task_api_contracts_1.FetchAndLockRequestPayload(workerId, topicName, maxTasks, longPollingTimeout, lockDuration);
        const httpResponse = await this.httpClient.post(url, payload, requestAuthHeaders);
        return httpResponse.result;
    }
    async extendLock(identity, workerId, externalTaskId, additionalDuration) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = external_task_api_contracts_1.restSettings.paths.extendLock
            .replace(external_task_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new external_task_api_contracts_1.ExtendLockRequestPayload(workerId, additionalDuration);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async handleBpmnError(identity, workerId, externalTaskId, errorCode) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = external_task_api_contracts_1.restSettings.paths.handleBpmnError
            .replace(external_task_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new external_task_api_contracts_1.HandleBpmnErrorRequestPayload(workerId, errorCode);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = external_task_api_contracts_1.restSettings.paths.handleServiceError
            .replace(external_task_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new external_task_api_contracts_1.HandleServiceErrorRequestPayload(workerId, errorMessage, errorDetails);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async finishExternalTask(identity, workerId, externalTaskId, results) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = external_task_api_contracts_1.restSettings.paths.finishExternalTask
            .replace(external_task_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new external_task_api_contracts_1.FinishExternalTaskRequestPayload(workerId, results);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    createRequestAuthHeaders(identity) {
        const noAuthTokenProvided = !identity || typeof identity.token !== 'string';
        if (noAuthTokenProvided) {
            return {};
        }
        const requestAuthHeaders = {
            headers: {
                Authorization: `Bearer ${identity.token}`,
            },
        };
        return requestAuthHeaders;
    }
    applyBaseUrl(url) {
        return `${this.baseUrl}${url}`;
    }
}
exports.ExternalTaskApiExternalAccessor = ExternalTaskApiExternalAccessor;
//# sourceMappingURL=external_accessor.js.map